package xyz.lychee.lagfixer.libs.adventure.internal.properties;

import java.util.function.Function;
import xyz.lychee.lagfixer.libs.annotations.NotNull;
import xyz.lychee.lagfixer.libs.annotations.Nullable;
import xyz.lychee.lagfixer.libs.annotations.ApiStatus.Internal;
import xyz.lychee.lagfixer.libs.annotations.ApiStatus.NonExtendable;

@Internal
public final class AdventureProperties {
   public static final Property<Boolean> DEBUG = property("debug", Boolean::parseBoolean, false);
   public static final Property<String> DEFAULT_TRANSLATION_LOCALE = property("defaultTranslationLocale", Function.identity(), (Object)null);
   public static final Property<Boolean> SERVICE_LOAD_FAILURES_ARE_FATAL;
   public static final Property<Boolean> TEXT_WARN_WHEN_LEGACY_FORMATTING_DETECTED;

   private AdventureProperties() {
   }

   @NotNull
   public static <T> @NotNull Property<T> property(final @NotNull String name, final @NotNull Function<String, T> parser, final @Nullable T defaultValue) {
      return AdventurePropertiesImpl.property(name, parser, defaultValue);
   }

   static {
      SERVICE_LOAD_FAILURES_ARE_FATAL = property("serviceLoadFailuresAreFatal", Boolean::parseBoolean, Boolean.TRUE);
      TEXT_WARN_WHEN_LEGACY_FORMATTING_DETECTED = property("text.warnWhenLegacyFormattingDetected", Boolean::parseBoolean, Boolean.FALSE);
   }

   @Internal
   @NonExtendable
   public interface Property<T> {
      @Nullable T value();
   }
}
